@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 # @Author: Anderson
 # @Date:   2019-11-11 17:42:18
-# @Last Modified by:   Anderson
-# @Last Modified time: 2019-12-30 12:39:47
+# @Last Modified by:   ander
+# @Last Modified time: 2020-03-03 13:51:10
 from openpyxl import Workbook
 import requests
 from bs4 import BeautifulSoup
 from urllib.parse import quote_plus
 import pdfplumber
+from PyPDF2 import PdfFileReader, PdfFileWriter, PdfFileMerger
 import jieba
 import os
 import re
 import json
 from pyecharts import options as opts
-from pyecharts.globals import ThemeType
 from pyecharts.charts import Bar
 from pyecharts.charts import WordCloud
 from copy import copy
@@ -27,6 +27,11 @@ def validate_title(title):
 	return new_title
 
 
+def mkdir(folder):
+	if not os.path.exists(folder):
+		os.mkdir(folder)
+
+
 class WebCrawlerBot(object):
 	"""docstring for WebCrawlerBot"""
 
@@ -85,7 +90,7 @@ class WebCrawlerBot(object):
 		url = f'https://www.liepin.com/zhaopin/?key={quote_plus(keyword)}&curPage={page}'
 		req = requests.get(url, headers=self.headers)
 		soup = BeautifulSoup(req.text, 'lxml')
-		result = []
+		results = []
 		for item in soup.select('.sojob-item-main'):
 			job_name = item.select('h3 a')[0].text.strip()
 			job_company = item.select('.company-name')[0].text.strip()
@@ -94,24 +99,29 @@ class WebCrawlerBot(object):
 			if job_salary == '面议':
 				annual_salary = -1
 			else:
-				min_salary = int(job_salary[:job_salary.index('-')])
-				max_salary = int(job_salary[job_salary.index('-') + 1:job_salary.index('k')])
-				months = int(job_salary[job_salary.index('·') + 1:-1])
-				annual_salary = (min_salary + max_salary) / 2 * months * 1000
+				if '-' in job_salary:
+					min_salary = int(job_salary[:job_salary.index('-')])
+					max_salary = int(job_salary[job_salary.index('-') + 1:job_salary.index('k')])
+					months = int(job_salary[job_salary.index('·') + 1:-1])
+					annual_salary = (min_salary + max_salary) / 2 * months * 1000
+				else:
+					monthly_salary = int(job_salary.split('k')[0])
+					months = int(job_salary[job_salary.index('·') + 1:-1])
+					annual_salary = monthly_salary * months * 1000
 			job_area = item.select('.condition .area')[0].text.strip()
 			job_edu = item.select('.condition .edu')[0].text.strip()
 			job_experience = item.select('.condition span')[-1].text.strip()
-			result.append([job_name, job_company, job_field, job_salary, annual_salary, job_area, job_edu, job_experience])
-		return result
+			results.append([job_name, job_company, job_field, job_salary, annual_salary, job_area, job_edu, job_experience])
+		return results
 
 	def get_huaban(self, keyword, page, key='k4rwsxf5'):
-		url = f"https://huaban.com/search/?q={quote_plus(keyword)}&type=pins&{key}&page={page-1}&per_page=20&wfl=1"
+		url = f"https://huaban.com/search/?q={quote_plus(keyword)}&type=pins&{key}&page={page+1}&per_page=20&wfl=1"
 		req = requests.get(url, headers=self.headers)
 		source = str(req.text)
 		start_index = source.index('app.page["pins"] = ') + len('app.page["pins"] = ')
-		end_index = source[start_index:].index('app.page["page"]')
+		end_index = start_index + source[start_index:].index('app.page["page"]')
 		results = []
-		for img in json.loads(source[start_index:start_index + end_index].strip()[:-1]):
+		for img in json.loads(source[start_index:end_index].strip()[:-1]):
 			results.append({
 				'url': f"https://hbimg.huabanimg.com/{img['file']['key']}",
 				'name': validate_title(f"{img['board']['title']}-{img['pin_id']}.jpg")
@@ -120,10 +130,9 @@ class WebCrawlerBot(object):
 		return results
 
 	def download_image(self, url, filename, folder):
-		if not os.path.exists(folder):
-			os.mkdir(folder)
+		mkdir(folder)
 		req = requests.get(url)
-		with open(os.path.join(folder, f'{filename}.jpg'), 'wb') as f:
+		with open(os.path.join(folder, f'{filename}'), 'wb') as f:
 			f.write(req.content)
 
 
@@ -174,14 +183,30 @@ class PDFBot(object):
 	"""docstring for ExcelBot"""
 
 	def __init__(self):
-		self.pdf = None
+		self.page_num = 0
 
-	def open(self, filename):
-		self.pdf = open(pdfplumber.open(filename))
+	def open(self, file_path):
+		self.filename, _ = os.path.splitext(os.path.basename(file_path))
+		self.pdf = pdfplumber.open(file_path)
+		self.pdf_reader = PdfFileReader(file_path)
+		self.page_num = self.pdf_reader.getNumPages()
 
-	def save(self, filename):
-		self.filename = filename
-		self.workbook.save(filename=f'{filename}.xlsx')
+	def get_text(self, page):
+		pdf_page = self.pdf.pages[page]
+		return pdf_page.extract_text()
+
+	def split(self, page, folder):
+		mkdir(folder)
+		pdf_writer = PdfFileWriter()
+		pdf_writer.addPage(self.pdf_reader.getPage(page))
+		with open(os.path.join(folder, f'{self.filename}-p{page}.pdf'), 'wb') as out:
+			pdf_writer.write(out)
+
+	def merge(self, pdfs, merged_name):
+		merger = PdfFileMerger()
+		for pdf in pdfs:
+			merger.append(PdfFileReader(pdf))
+		merger.write(f"{merged_name}.pdf")
 
 
 class DataAnalysisBot(object):
